Stan Math Library: stan::math::store_type< int > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::math::store_type< int > Struct Template Reference

`#include <seq_view.hpp>`

## Public Types
typedef const int | type

## Detailed Description

### template<>
struct stan::math::store_type< int >

Definition at line 21 of file seq_view.hpp.

## Member Typedef Documentation

typedef const int stan::math::store_type< int >::type

Definition at line 22 of file seq_view.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/mat/meta/seq_view.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.